@@ -35,6 +35,8 @@ class RabbitMQPublisher:
                 try:
                     self.__connect_and_flush_messages()
                 except Exception:
+                    if logger.isEnabledFor(logging.DEBUG):
+                        logger.exception("__connect_and_flush_messages exception")
                     time.sleep(1)
         finally:
             self.done.set()
@@ -108,6 +110,8 @@ class RabbitMQConsumer:
                 try:
                     self.__connect_and_consume_messages()
                 except Exception:
+                    if logger.isEnabledFor(logging.DEBUG):
+                        logger.exception("__connect_and_consume_messages exception")
                     time.sleep(1)
         finally:
             self.done.set()
@@ -119,8 +123,10 @@ class RabbitMQConsumer:
             # setup subscriber queue and bind to topics
             queue = ch.queue_declare("", exclusive=True).method.queue
             ch.basic_consume(queue, self.__process_message, auto_ack=True)
-            ch.queue_bind(queue, "data.topic", self.topics)
-            logger.debug("consumer binding queue %s to topics %s", queue, self.topics)
+
+            for topic in self.topics:
+                ch.queue_bind(queue, "data.topic", topic)
+                logger.debug("consumer binding queue %s to topic %s", queue, topic)
 
             def check_stop():
                 if self.stop.is_set():
